# 4Code Software Developement Kit
#### Common functions in one place.


This library is written for economy time of developement.
Common usage tools in one touch. Free license.


### Authors nicnames:
<ul>
<li> AngryDanny+ </li>
<li> N_XY </li>
</ul>
